<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Visualitzador d&apos;imatges del Deepin</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>Versió:</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>El Visualitzador d&apos;imatges del Deepin és un gestor d&apos;imatges modern i fàcil d&apos;usar.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Té les funcions de gestió, visualització i edició bàsica d&apos;imatges.</translation>
    </message>
</context>
<context>
    <name>AlbumBTContent</name>
    <message>
        <source>image</source>
        <translation>imatge</translation>
    </message>
    <message>
        <source>images</source>
        <translation>imatges</translation>
    </message>
    <message>
        <source>album</source>
        <translation>àlbum</translation>
    </message>
    <message>
        <source>albums</source>
        <translation>àlbums</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Gestió de sincronització</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sincronització: </translation>
    </message>
</context>
<context>
    <name>AlbumCreateDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Àlbum nou</translation>
    </message>
    <message>
        <source>Unnamed</source>
        <translation>Sense nom</translation>
    </message>
</context>
<context>
    <name>AlbumDelegate</name>
    <message>
        <source>Recent imported</source>
        <translation>Importat de fa poc</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favorits</translation>
    </message>
</context>
<context>
    <name>AlbumDeleteDialog</name>
    <message>
        <source>Are your sure to delete this album?</source>
        <translation>Segur que voleu eliminar aquest àlbum?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>AlbumPanel</name>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Timeline</source>
        <translation>Línia temporal</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Afegeix</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Podeu afegir una directori de sincronització i deixar anar imatges a la línia temporal.</translation>
    </message>
</context>
<context>
    <name>AlbumsView</name>
    <message>
        <source>Unnamed</source>
        <translation>Sense nom</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia&apos;n el nom</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>Application</name>
    <message>
        <source>Deepin Image Viewer</source>
        <translation>Visualitzador d&apos;imatges del Deepin</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Imatges</translation>
    </message>
</context>
<context>
    <name>DirImportDialog</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <source>Are you sure to add the pictures to the album?</source>
        <translation>Segur que voleu afegir imatges a aquest àlbum?</translation>
    </message>
    <message>
        <source>Sync and Create</source>
        <translation>Sincronitza i crea</translation>
    </message>
    <message>
        <source>Sync</source>
        <translation>Sincronització</translation>
    </message>
    <message>
        <source>Are you sure to add to the sync list and create the album named after this folder?</source>
        <translation>Segur que ho voleu afegir a la llista de sincronització i crear l&apos;àlbum amb el nom d&apos;aquesta carpeta?</translation>
    </message>
</context>
<context>
    <name>Exporter</name>
    <message>
        <source>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</source>
        <translation>JPEG(*.bmp *.gif *.jpg; *.jpeg; *.png *.pbm;*.pgm *.ppm *.xbm *.xpm *.svg *.dds *.icns*.jp2 *.mng *.tga *.tiff *.wbmp *.webp;)</translation>
    </message>
    <message>
        <source>Exported successfully</source>
        <translation>Exportat correctament</translation>
    </message>
    <message>
        <source>Failed to export</source>
        <translation>Ha fallat l&apos;exportació</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Desa</translation>
    </message>
</context>
<context>
    <name>FileDeleteDialog</name>
    <message>
        <source>Are you sure to throw pictures to TRASH?</source>
        <translation>Segur que voleu llençar les imatges a la paperera?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Aquest fitxer conté múltiples pàgines. Si us plau, useu l&apos;Evince per veure-les totes.</translation>
    </message>
</context>
<context>
    <name>ImagesView</name>
    <message>
        <source>View</source>
        <translation>Visualització</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimeix</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copia al porta-retalls</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Llença a la paperera</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Elimina de l&apos;àlbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Estableix com a fons d&apos;escriptori</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Afegeix</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Podeu afegir una directori de sincronització i deixar anar imatges a la línia temporal.</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Afegeix a l&apos;àlbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Afegeix a un àlbum nou</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Obre un directori</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>No teniu permís per veure la imatge.</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <source>Date photoed</source>
        <translation>Data de fotografia</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data de modificació</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resolució</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Mida del fitxer</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espai de color</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mode d&apos;exposició</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa d&apos;exposició</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Hora d&apos;exposició</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flaix</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Obertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Llargada focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Obertura màxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mode de mesura</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balanç de blanc</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensació del flaix</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model de la càmera</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model de la lent</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Sense escalar</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Ajusta la pàgina a la imatge</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Ajusta la imatge a la pàgina</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Escala a:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milímetres</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centímetres</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Polzades</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Posició de la imatge</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Escala</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Configuració de la imatge</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Persianes</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Commutador</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Lliscament</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Anell</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Directori seleccionat</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Aquest directori està inhabilitat per a la sincronització.</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Afegeix una capeta</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Gestió del directori de sincronització</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>La llista de directoris és buida.</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Cancel·la la sincronització</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>El dispositiu s&apos;ha extret.</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Aquest directori ja no existeix.</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Calculant...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visualització d&apos;imatges</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Àlbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Acaba la presentació</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Llença a la paperera</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Elimina de l&apos;àlbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Estableix com a fons d&apos;escriptori</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Pantalla anterior</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Pantalla següent</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Àlbum nou</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia&apos;n el nom</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Si us plau, introduïu una drecera nova.</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Dreceres</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Mostra la imatge</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Àlbum</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Restableix els valors per defecte</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Visualització</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Acaba la presentació</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimeix</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Llença a la paperera</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Elimina de l&apos;àlbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Estableix com a fons d&apos;escriptori</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Àlbum nou</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia&apos;n el nom</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>SlideShowPanel</name>
    <message>
        <source>End show</source>
        <translation>Acaba la presentació</translation>
    </message>
    <message>
        <source>Pause/Play</source>
        <translation>Pausa / Reprodueix</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Paràmetres de la presentació</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Efecte de canvi</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durada</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Durada del canvi</translation>
    </message>
    <message>
        <source>second</source>
        <translation>segon</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Gestió de la imatge</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favorits</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Mida 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajusta a la finestra</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Throw to Trash</source>
        <translation>Llença a la paperera</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>No s&apos;ha trobat cap fitxer d&apos;imatge.</translation>
    </message>
</context>
<context>
    <name>TimelineBTContent</name>
    <message>
        <source>%1 image</source>
        <translation>%1 imatge</translation>
    </message>
    <message>
        <source>%1 images</source>
        <translation>%1 imatges</translation>
    </message>
    <message>
        <source>Manage sync</source>
        <translation>Gestió de sincronització</translation>
    </message>
    <message>
        <source>Syncing: </source>
        <translation>Sincronització: </translation>
    </message>
</context>
<context>
    <name>TimelinePanel</name>
    <message>
        <source>Album</source>
        <translation>Àlbum</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Afegeix</translation>
    </message>
    <message>
        <source>You can add sync directory or drag and drop  images to timeline</source>
        <translation>Podeu afegir una directori de sincronització i deixar anar imatges a la línia temporal.</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Afegeix a l&apos;àlbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Afegeix a un àlbum nou</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualització</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimeix</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copia al porta-retalls</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Llença a la paperera</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Estableix com a fons d&apos;escriptori</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Paràmetres de la presentació</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efecte</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durada</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Dreceres</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Àlbum</translation>
    </message>
</context>
<context>
    <name>TopAlbumTips</name>
    <message>
        <source>dd MMMM yyyy</source>
        <translation>dd mmmm aaaa</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favorits</translation>
    </message>
    <message>
        <source>Recent imported</source>
        <translation>Importat de fa poc</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Àlbum nou</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>Deepin Image Viewer is a fashion &amp; smooth image manager.</source>
        <translation>El Visualitzador d&apos;imatges del Deepin és un gestor d&apos;imatges modern i fàcil d&apos;usar.</translation>
    </message>
    <message>
        <source>It is featured with image management, image viewing and basic image editing.</source>
        <translation>Té les funcions de gestió, visualització i edició bàsica d&apos;imatges.</translation>
    </message>
    <message>
        <source>Dark theme</source>
        <translation>Tema fosc</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Línia temporal</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Afegeix a l&apos;àlbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Afegeix a un àlbum nou</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Surt de la pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimeix</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Copia al porta-retalls</translation>
    </message>
    <message>
        <source>Throw to trash</source>
        <translation>Llença a la paperera</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Elimina de l&apos;àlbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostra la finestra de navegació</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Amaga la finestra de navegació</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Estableix com a fons d&apos;escriptori</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
</context>
</TS>